@@ -9,11 +9,11 @@ import peewee as pw
 class MigrateHistory(pw.Model):
     """Presents the migrations in database."""
 
-    id = pw.AutoField()  # noqa:
+    id = pw.AutoField()
     name = pw.CharField()
     migrated_at = pw.DateTimeField(default=dt.datetime.utcnow)
 
-    def __unicode__(self) -> str:
+    def __str__(self) -> str:
         """String representation."""
         return self.name  # type: ignore[]
 
