@@ -2,11 +2,11 @@
 
 from __future__ import annotations
 
-from typing import Any, Dict, Type, TypeVar
+from typing import Any, TypeVar
 
 from peewee import Model
 
-TModelType = Type[Model]
-TParams = Dict[str, Any]
+TModelType = type[Model]
+TParams = dict[str, Any]
 
 TVModelType = TypeVar("TVModelType", bound=TModelType)
